@@ -1,8 +1,8 @@
 package RedisDB::Error;
 
 use strict;
-use base 'RedisDB::Parser::Error';
-our $VERSION = "2.48_01";
+use warnings;
+our $VERSION = "2.01";
 $VERSION = eval $VERSION;
 
 =head1 NAME
@@ -21,24 +21,34 @@ RedisDB::Error - Error class for RedisDB
 
 Object of this class maybe passed as argument to callback specified in
 I<send_command_cb> if redis server return error.  In string context object
-returns description of the error. This class inherits from
-L<RedisDB::Parser::Error>.
+returns description of the error.
+
+=head1 METHODS
 
 =cut
 
-*new = \&RedisDB::Parser::Error::new;
+use overload '""' => \&as_string;
 
-package RedisDB::Error::EAGAIN;
-our @ISA = qw(RedisDB::Error);
+=head2 $class->new($message)
 
-package RedisDB::Error::DISCONNECTED;
-our @ISA = qw(RedisDB::Error);
+Create new error object with specified error message.
 
-package RedisDB::Error::MOVED;
-our @ISA = qw(RedisDB::Parser::Error::MOVED RedisDB::Error);
+=cut
 
-package RedisDB::Error::ASK;
-our @ISA = qw(RedisDB::Parser::Error::ASK RedisDB::Error);
+sub new {
+    my ($class, $message) = @_;
+    return bless { message => $message }, $class;
+}
+
+=head2 $self->as_string
+
+Return error message. Also you can just use object in string context.
+
+=cut
+
+sub as_string {
+    return shift->{message};
+}
 
 1;
 
@@ -54,7 +64,7 @@ Pavel Shaydo, C<< <zwon at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2015 Pavel Shaydo.
+Copyright 2011, 2012 Pavel Shaydo.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
