@@ -2,12 +2,12 @@ package RedisDB::Parse::Redis_PP;
 
 use strict;
 use warnings;
-our $VERSION = "2.13_06";
+our $VERSION = "2.01";
 $VERSION = eval $VERSION;
 
 =head1 NAME
 
-RedisDB::Parse::Redis_PP - redis protocol parser for RedisDB
+RedisDB::Parse::Redis - redis protocol parser for RedisDB
 
 =head1 DESCRIPTION
 
@@ -64,15 +64,6 @@ sub callbacks {
     @{ shift->{_callbacks} };
 }
 
-sub propagate_reply {
-    my ( $self, $reply ) = @_;
-    $self->{_default_cb}->( $self->{redisdb}, $reply ) if $self->{_default_cb};
-    while ( my $cb = shift @{ $self->{_callbacks} } ) {
-        $cb->( $self->{redisdb}, $reply );
-    }
-    return;
-}
-
 sub add {
     my ( $self, $data ) = @_;
     $self->{_buffer} .= $data;
@@ -263,7 +254,7 @@ Pavel Shaydo, C<< <zwon at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2013 Pavel Shaydo.
+Copyright 2011, 2012 Pavel Shaydo.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
